## JPyDB

### Introduction
JPyDB is a python library developed by Manuel Sánchez Mascarell.
The main purpose of this library is to create and manage NoSQL databases in you local machine. This database uses JSON files for store the data.

#### COMING SOON ####